/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnChanges } from '@angular/core';
import { MultiSelectTreeComponent } from '../multiselecttree.component';
import * as i0 from "@angular/core";
/**
 * A directive which configures the MultiSelectTree to show one single summary tag for all selected data items.
 * When a number is provided, the summary tag is displayed after the given amount of data items are selected
 * ([more information and examples]({% slug api_dropdowns_multiselecttreesummarytagdirective %})).
 *
 * @example
 * ```ts-no-run
 * <kendo-multiselecttree kendoMultiSelectTreeSummaryTag [data]="data"></kendo-multiselecttree>
 * ```
 *
 * @example
 * ```ts-no-run
 * <kendo-multiselecttree [kendoMultiSelectTreeSummaryTag]="2" [data]="data"></kendo-multiselecttree>
 * ```
 */
export declare class MultiSelectTreeSummaryTagDirective implements OnChanges {
    private multiSelectTreeComponent;
    /**
     * A numeric value that indicates the number of selected data items after which the summary tag will appear.
     */
    showAfter: number | string;
    constructor(multiSelectTreeComponent: MultiSelectTreeComponent);
    ngOnChanges(changes: any): void;
    private createTagMapper;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiSelectTreeSummaryTagDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MultiSelectTreeSummaryTagDirective, "[kendoMultiSelectTreeSummaryTag]", never, { "showAfter": { "alias": "kendoMultiSelectTreeSummaryTag"; "required": false; }; }, {}, never, never, true, never>;
}
